/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.query;

import org.apache.druid.timeline.DataSegment;

import javax.annotation.Nullable;

public class DataSegmentAndDescriptor
{
  public static DataSegmentAndDescriptor missing(SegmentDescriptor descriptor)
  {
    return new DataSegmentAndDescriptor(null, descriptor);
  }

  @Nullable
  private final DataSegment dataSegment;
  private final SegmentDescriptor descriptor;

  public DataSegmentAndDescriptor(@Nullable DataSegment dataSegment, SegmentDescriptor descriptor)
  {
    this.dataSegment = dataSegment;
    this.descriptor = descriptor;
  }

  @Nullable
  public DataSegment getDataSegment()
  {
    return dataSegment;
  }

  public SegmentDescriptor getDescriptor()
  {
    return descriptor;
  }
}
